@@ -241,9 +241,9 @@ class DeepModelMixin(SemiEstimator):
                 if len(self._augmentation) > 1:
                     self.strong_augmentation = self._augmentation[1]
             else:
-                self.weak_augmentation = copy.deepcopy(self._augmentation)
+                self.weak_augmentation = copy.copy(self._augmentation)
             if self.strong_augmentation is None:
-                self.strong_augmentation = copy.deepcopy(self.weak_augmentation)
+                self.strong_augmentation = copy.copy(self.weak_augmentation)
 
     def init_transform(self):
         if self.weak_augmentation is not None:
@@ -341,7 +341,7 @@ class DeepModelMixin(SemiEstimator):
                 self.evaluate(X=valid_X,y=valid_y,valid=True)
                 self.valid_performance.update({"epoch_" + str(self._epoch) + "_it_" + str(self.it_epoch): self.performance})
 
-        if valid_X is not None and self.epoch%self.eval_epoch!=0:
+        if valid_X is not None and (self.eval_epoch is None or self.epoch% self.eval_epoch!=0):
             self.evaluate(X=valid_X, y=valid_y, valid=True)
             self.valid_performance.update({"epoch_" + str(self._epoch) + "_it_" + str(self.it_epoch): self.performance})
 
